@@ -34,7 +34,7 @@ load_image (gpointer data,
   GError *error = NULL;
 
   loader = gdk_pixbuf_loader_new ();
-  path = g_test_get_filename (G_TEST_DIST, "test-images", filename, NULL);
+  path = g_test_get_filename (G_TEST_DIST, "test-images/randomly-modified", filename, NULL);
 
   g_test_message ("reading %s", path); 
   file = fopen (path, "r");
@@ -73,23 +73,21 @@ test_threads (void)
   for (i = 0; i < iterations; i++)
     {
       if (format_supported ("jpeg"))
-        g_thread_pool_push (pool, "valid_jpeg_test", NULL);
+        g_thread_pool_push (pool, "valid.1.jpeg", NULL);
       if (format_supported ("png"))
-        g_thread_pool_push (pool, "valid_png_test", NULL);
+        g_thread_pool_push (pool, "valid.1.png", NULL);
       if (format_supported ("gif"))
-        g_thread_pool_push (pool, "valid_gif_test", NULL);
+        g_thread_pool_push (pool, "valid.1.gif", NULL);
       if (format_supported ("bmp"))
-        g_thread_pool_push (pool, "valid_bmp_test", NULL);
+        g_thread_pool_push (pool, "valid.1.bmp", NULL);
       if (format_supported ("jpeg"))
-        g_thread_pool_push (pool, "valid_jpeg_progressive_test", NULL);
+        g_thread_pool_push (pool, "valid.2.jpeg", NULL);
       if (format_supported ("xpm"))
-        g_thread_pool_push (pool, "valid_xpm_test", NULL);
-      if (format_supported ("ras"))
-        g_thread_pool_push (pool, "valid_ras_test", NULL);
+        g_thread_pool_push (pool, "valid.1.xpm", NULL);
       if (format_supported ("tga"))
-        g_thread_pool_push (pool, "valid_tga_test", NULL);
+        g_thread_pool_push (pool, "valid.1.tga", NULL);
       if (format_supported ("tiff"))
-        g_thread_pool_push (pool, "valid_tiff1_test", NULL);
+        g_thread_pool_push (pool, "valid.1.tiff", NULL);
     }
 
   g_thread_pool_free (pool, FALSE, TRUE);
